@@ -661,7 +661,7 @@ class IconChooser(SettingsWidget):
     bind_prop = "icon"
     bind_dir = Gio.SettingsBindFlags.DEFAULT
 
-    def __init__(self, label, expand_width=False, size_group=None, dep_key=None, tooltip=""):
+    def __init__(self, label, default_icon=None, icon_categories=[], default_category=None, expand_width=False, size_group=None, dep_key=None, tooltip=""):
         super(IconChooser, self).__init__(dep_key=dep_key)
 
         self.label = SettingsLabel(label)
@@ -669,6 +669,16 @@ class IconChooser(SettingsWidget):
         self.content_widget = XApp.IconChooserButton()
         self.content_widget.set_icon_size(Gtk.IconSize.BUTTON)
 
+        dialog = self.content_widget.get_dialog()
+        if default_icon:
+            dialog.set_default_icon(default_icon)
+
+        for category in icon_categories:
+            dialog.add_custom_category(category['name'], category['icons'])
+
+        if default_category is not None:
+            self.content_widget.set_default_category(default_category)
+
         self.pack_start(self.label, False, False, 0)
         self.pack_end(self.content_widget, expand_width, expand_width, 0)
 
